==> tine20-allinone_2019.12.5.tar.bz2: Crm/js/Crm-lang-de-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-12-13 09:53+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: German (http://www.transifex.com/tine20/tine20/language/de/)\nLanguage: de\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Customer"
: "Kunde"

, "State"
: "Status"

, "Role"
: "Rolle"

, "Source"
: "Quelle"

, "Start"
: "Start"

, "Scheduled end"
: "geplantes Ende"

, "End"
: "Ende"

, "Turnover"
: "Umsatz"

, "Probability"
: "Wahrscheinlichkeit"

, "Folder"
: "Ordner"

, "Updated by"
: "Aktualisiert von"

, "Updated Fields:"
: "Geänderte Felder:"

, "'%s' changed from '%s' to '%s'."
: "'%s' wurde von '%s' auf '%s' geändert."

, "Tags"
: "Tags"

, "Lead %s has been changed"
: "Lead %s wurde geändert"

, "Lead %s has been deleted"
: "Lead %s wurde gelöscht"

, "Lead %s has been created"
: "Lead %s wurde angelegt"

, "Lead Data"
: "Lead-Daten"

, "Leadstate"
: "Status"

, "Leadtype"
: "Typ"

, "Leadsource"
: "Quelle"

, "End Scheduled"
: "geplantes Ende"

, "Contacts"
: "Kontakte"

, "Address"
: "Anschrift"

, "Telephone"
: "Telefon"

, "Email"
: "Email"

, "Tasks"
: "Aufgaben"

, "Due Date"
: "Fälligkeitsdatum"

, "Priority"
: "Priorität"

, "Products"
: "Produkte"

, "low"
: "Niedrig"

, "normal"
: "Normal"

, "high"
: "Hoch"

, "urgent"
: "Dringend"

, "All leads I have read grants for"
: "Alle Leads für die ich Lese-Rechte habe"

, "Last modified by me"
: "Zuletzt von mir bearbeitet"

, "All leads that I have last modified"
: "Alle Leads, die ich zuletzt bearbeitet habe"

, "My leads"
: "Meine Leads"

, "All leads that I am responsible for"
: "Alle Leads, für die ich verantwortlich bin"

, "Leads with overdue tasks"
: "Leads mit überfälligen Aufgaben"

, "All leads"
: "Alle Leads"

, "Default Lead List"
: "Standard-Leadliste"

, "The default list for new leads"
: "Die Standard-Leadliste, in der neue Leads angelegt werden."

, "Get Notification Emails"
: "Benachrichtigungsemails empfangen"

, "The level of actions you want to be notified about."
: "Der Grad an Aktionen über die Sie benachrichtigt werden wollen."

, "Send Notifications Emails for own actions"
: "Sende Benachrichtigungen über eigene Änderungen"

, "Get notifications emails for actions you did yourself"
: "Empfangen von Benachrichtigungen über Änderungen die selbst getätigt wurden"

, "Send Notifications Emails to responsible"
: "Sende Benachrichtigungen zu den Verantwortlichen"

, "Get notifications emails for action to responsible"
: "Empfangen von Benachrichtigungen über Änderungen für den Verantwortlichen"

, "Send Notifications Emails to customer"
: "Sende Benachrichtigungen zu den Kunden"

, "Get notifications emails for action to customer"
: "Empfangen von Benachrichtigungen über Änderungen für den Kunden"

, "Send Notifications Emails to partner"
: "Sende Benachrichtigungen zu den Partnern"

, "Get notifications emails for action to partner"
: "Empfangen von Benachrichtigungen über Änderungen für die Partner"

, "Default Favorite"
: "Standard Favorit"

, "The default favorite which is loaded on crm startup"
: "Der Standard Favorit der beim öffnen des Crm geladen wird"

, "manage shared lead folders"
: "Gemeinsame Leads Ordner bearbeiten"

, "Create new shared lead folders"
: "Anlegen von gemeinsamen Leads Ordnern"

, "manage shared leads favorites"
: "Gemeinsame Lead-Favoriten verwalten"

, "Create or update shared leads favorites"
: "Gemeinsame Lead-Favoriten erstellen oder bearbeiten"

, "Contact"
: "Kontakt"

, "CRM Role"
: "CRM Rolle"

, "Lead, Leads"
: [
  "Lead"
 ,"Lead"

]
, "lead list, lead lists"
: [
  "Leadliste"
 ,"Leadlisten"

]
, "lead lists"
: "Leadlisten"

, "Quick Search"
: "Schnellsuche"

, "Lead name"
: "Lead-Name"

, "Last Modified Time"
: "Zuletzt geändert"

, "Last Modified By"
: "Zuletzt geändert von"

, "Creation Time"
: "Erstelldatum"

, "Created By"
: "Angelegt von"

, "Estimated end"
: "Geplantes Ende"

, "Resubmission Date"
: "Wiedervorlagedatum"

, "X Lead"
: "X Lead"

, "Archived"
: "Archiviert"

, "Partner"
: "Partner"

, "Phone"
: "Telefon"

, "Mobile"
: "Handy"

, "Fax"
: "Fax"

, "E-Mail"
: "Email"

, "Web"
: "Webseite"

, "Street"
: "Straße"

, "Postalcode"
: "Postleitzahl"

, "City"
: "Ort"

, "Status"
: "Status"

, "Change type to Customer"
: "Kontakttyp auf Kunde setzen"

, "Responsible"
: "Verantwortlicher"

, "Change type to Responsible"
: "Kontakttyp auf Verantwortlicher setzen"

, "Change type to Partner"
: "Kontakttyp auf Partner setzen"

, "Change contact type"
: "Kontakttyp ändern"

, "Search for Contacts to add ..."
: "Kontakte zum Hinzufügen suchen..."

, "Name"
: "Name"

, "Data"
: "Daten"

, "Cellphone"
: "Telefon (Mobil)"

, "Add new {0}"
: "Neuen {0} hinzufügen"

, "Unlink {0}"
: "Entferne {0}"

, "Unlink selected {0}"
: "Ausgewählte {0} entfernen"

, "Edit {0}"
: "{0} bearbeiten"

, "Edit selected {0}"
: "Ausgewählten {0} bearbeiten"

, "No Tasks to display"
: "Keine Aufgaben vorhanden"

, "Summary"
: "Zusammenfassung"

, "Add a task..."
: "Aufgabe hinzufügen..."

, "Percent"
: "Prozent"

, "Organizer"
: "Organisator"

, "Please choose the Lead to add the contacts to"
: "Bitte wählen Sie den Lead, zu dem die Kontakte hinzugefügt werden sollen"

, "Please select the attenders' role"
: "Bitte wählen Sie die Rolle des Teilnehmers"

, "Select Lead"
: "Lead auswählen"

, "Select Role"
: "Rolle auswählen"

, "Adding {0} contacts to lead"
: "Füge {0} Kontakte zum Lead hinzu"

, "Probable Turnover"
: "Voraussichtlicher Umsatz"

, "Import leads"
: "Leads importieren"

, "You do not have the run right for the Tasks application or it is not activated."
: "Sie haben nicht das erforderliche Recht die Aufgaben-Anwendung zu benutzen oder sie ist deaktiviert."

, "You do not have the run right for the Sales application or it is not activated."
: "Sie haben nicht das erforderliche Recht die Sales-Anwendung zu benutzen oder sie ist deaktiviert."

, "Enter lead name"
: "Leadname eingeben"

, "Expected turnover"
: "Erwarteter Umsatz"

, "Description"
: "Beschreibung"

, "Enter description"
: "Beschreibung eingeben"

, "New Lead"
: "Neuer Lead"

, "Product"
: "Produkt"

, "Price"
: "Preis"

, "Quantity"
: "Anzahl"

, "Search for Products to add ..."
: "Produkte zum Hinzufügen suchen..."

, "Edit new lead"
: "Neuen Lead bearbeiten"

, "The following leads have just been imported into lead list %s"
: "Die folgenden Leads wurden soeben in die Lead Liste %s importiert"

, "%s new leads have been imported"
: "%s neue Leads wurden importiert"

, "Lead CSV import"
: "Lead CSV import"

, "Import list (###CURRENTDATE###)"
: "Importierte Liste (###CURRENTDATE###)"

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Leads importiert am ###CURRENTDATE### um ###CURRENTTIME### von ###USERFULLNAME###"

, "Task"
: "Aufgabe"

, "Lead States Available"
: "Verfügbare Lead Status"

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "offen"

, "contacted"
: "kontaktiert"

, "waiting for feedback"
: "Wartet auf Feedback"

, "quote sent"
: "Quote gesendet"

, "accepted"
: "akzeptiert"

, "lost"
: "verloren"

, "Lead Sources Available"
: "Verfügbare Lead Quellen"

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: "Verfügbare Lead Typen"

, "Possible lead types."
: "Mögliche Lead Typen."

, "Reseller"
: "Reseller"

, "Enabled Features"
: "Feature aktivieren"

, "Enabled Features in Crm Application."
: "Features in der Crm Applikation aktivieren"

, "Lead Import"
: "Lead Import"

, "Add new task on lead import"
: "Füge eine neue Aufgabe beim Lead Import hinzu"

, "Automatically creates a task for the responsible person if a new lead is imported."
: "Lege automatisch eine neue Aufgabe für die verantwortliche Person an, wenn ein neuer Lead importiert wird."

, "Send notification email on lead import"
: "Sende Benachrichtigungen beim Lead Import"

, "Sends an email to all responsible persons for the imported leads."
: "Sende für die importierten Leads eine E-Mail an alle verantwortlichen Personen."

, "Lead duplicate check fields"
: "Lead-Dublettencheck Felder"

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "Diese Felder werden überprüft, wenn ein neuer Lead angelegt wird. Wenn ein Datensatz mit den selben Daten in diesem Feld gefunden wird, wird eine Dubletten Warnung geworfen."

, "All without me"
: "Alle außer mir"

, "All"
: "Alle"

, "Nobody"
: "Niemand"

, "send notification to responsible"
: "Versendet Benachrichtigungen zum Verantwortlichen"

, "send notification to customer"
: "Versendet Benachrichtigungen zum Kunden"

, "send notification to partner"
: "Versendet Benachrichtigungen zum Partner"

, "send notification"
: "Versendet Benachrichtigungen"

, "controls sending notification of Leads"
: "Steuert das versenden von Benachrichtigungen für Leads"
, "Lead"
: "Lead"

, "lead list"
: "Leadliste"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: Crm/js/Crm-lang-de-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-12-13 09:53+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: German (http://www.transifex.com/tine20/tine20/language/de/)\nLanguage: de\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "All leads"
: "Alle Leads"

, "Default Lead List"
: "Standard-Leadliste"

, "The default list for new leads"
: "Die Standard-Leadliste, in der neue Leads angelegt werden"

, "Get Notification Emails"
: "Benachrichtigungsemails empfangen"

, "The level of actions you want to be notified about."
: "Der Grad an Aktionen über die Sie benachrichtigt werden wollen."

, "Send Notifications Emails for own actions"
: "Sende Benachrichtigungen über eigene Änderungen"

, "Get notifications emails for actions you did yourself"
: "Empfangen von Benachrichtigungen über Änderungen die selbst getätigt wurden"

, "Send Notifications Emails to responsible"
: "Sende Benachrichtigungen zu den Verantwortlichen"

, "Get notifications emails for action to responsible"
: "Empfangen von Benachrichtigungen über Änderungen für den Verantwortlichen"

, "Send Notifications Emails to customer"
: "Sende Benachrichtigungen zu den Kunden"

, "Get notifications emails for action to customer"
: "Empfangen von Benachrichtigungen über Änderungen für den Kunden"

, "Send Notifications Emails to partner"
: "Sende Benachrichtigungen zu den Partnern"

, "Get notifications emails for action to partner"
: "Empfangen von Benachrichtigungen über Änderungen für die Partner"

, "Default Favorite"
: "Standard Favorit"

, "The default favorite which is loaded on crm startup"
: "Der Standard Favorit der beim öffnen des Crm geladen wird"

, "New Lead"
: "Neuer Lead"

, "Tags"
: "Tags"

, "Lead name"
: "Lead-Name"

, "Responsible"
: "Verantwortlicher"

, "Partner"
: "Partner"

, "Customer"
: "Kunde"

, "Leadstate"
: "Status"

, "Leadtype"
: "Typ"

, "Leadsource"
: "Quelle"

, "Probability"
: "Wahrscheinlichkeit"

, "Turnover"
: "Umsatz"

, "Estimated end"
: "Geplantes Ende"

, "Probable Turnover"
: "Voraussichtlicher Umsatz"

, "Resubmission Date"
: "Wiedervorlagedatum"

, "Import leads"
: "Leads importieren"

, "Contact"
: "Kontakt"

, "CRM Role"
: "CRM Rolle"

, "Tasks"
: "Aufgaben"

, "No Tasks to display"
: "Keine Aufgaben vorhanden"

, "Summary"
: "Zusammenfassung"

, "Add a task..."
: "Aufgabe hinzufügen..."

, "Due Date"
: "Fälligkeitsdatum"

, "Priority"
: "Priorität"

, "Percent"
: "Prozent"

, "Status"
: "Status"

, "Organizer"
: "Organisator"

, "Add new {0}"
: "Neuen {0} hinzufügen"

, "Unlink {0}"
: "Entferne {0}"

, "Unlink selected {0}"
: "Ausgewählte {0} entfernen"

, "Edit {0}"
: "{0} bearbeiten"

, "Edit selected {0}"
: "Ausgewählten {0} bearbeiten"

, "Please choose the Lead to add the contacts to"
: "Bitte wählen Sie den Lead, zu dem die Kontakte hinzugefügt werden sollen"

, "Please select the attenders' role"
: "Bitte wählen Sie die Rolle des Teilnehmers"

, "Lead, Leads"
: [
  "Lead"
 ,"Lead"

]
, "Select Lead"
: "Lead auswählen"

, "Role"
: "Rolle"

, "Select Role"
: "Rolle auswählen"

, "Adding {0} contacts to lead"
: "Füge {0} Kontakte zum Lead hinzu"

, "Phone"
: "Telefon"

, "Mobile"
: "Handy"

, "Fax"
: "Fax"

, "E-Mail"
: "Email"

, "Web"
: "Webseite"

, "Street"
: "Straße"

, "Postalcode"
: "Postleitzahl"

, "City"
: "Ort"

, "Start"
: "Start"

, "Change type to Customer"
: "Kontakttyp auf Kunde setzen"

, "Change type to Responsible"
: "Kontakttyp auf Verantwortlicher setzen"

, "Change type to Partner"
: "Kontakttyp auf Partner setzen"

, "Change contact type"
: "Kontakttyp ändern"

, "Search for Contacts to add ..."
: "Kontakte zum Hinzufügen suchen..."

, "Name"
: "Name"

, "Address"
: "Anschrift"

, "Data"
: "Daten"

, "Cellphone"
: "Telefon (Mobil)"

, "End"
: "Ende"

, "You do not have the run right for the Tasks application or it is not activated."
: "Sie haben nicht das erforderliche Recht die Aufgaben-Anwendung zu benutzen oder sie ist deaktiviert."

, "Products"
: "Produkte"

, "You do not have the run right for the Sales application or it is not activated."
: "Sie haben nicht das erforderliche Recht die Sales-Anwendung zu benutzen oder sie ist deaktiviert."

, "Enter lead name"
: "Leadname eingeben"

, "Expected turnover"
: "Erwarteter Umsatz"

, "Description"
: "Beschreibung"

, "Enter description"
: "Beschreibung eingeben"

, "lead list, lead lists"
: [
  "Leadliste"
 ,"Leadlisten"

]
, "lead lists"
: "Leadlisten"

, "Quick Search"
: "Schnellsuche"

, "Last Modified Time"
: "Zuletzt geändert"

, "Last Modified By"
: "Zuletzt geändert von"

, "Creation Time"
: "Erstelldatum"

, "Created By"
: "Angelegt von"

, "X Lead"
: "X Lead"

, "Archived"
: "Archiviert"

, "Product"
: "Produkt"

, "Price"
: "Preis"

, "Quantity"
: "Anzahl"

, "Search for Products to add ..."
: "Produkte zum Hinzufügen suchen..."

, "All leads I have read grants for"
: "Alle Leads für die ich Lese-Rechte habe"

, "Last modified by me"
: "Zuletzt von mir bearbeitet"

, "All leads that I have last modified"
: "Alle Leads, die ich zuletzt bearbeitet habe"

, "My leads"
: "Meine Leads"

, "All leads that I am responsible for"
: "Alle Leads, für die ich verantwortlich bin"

, "Leads with overdue tasks"
: "Leads mit überfälligen Aufgaben"

, "Lead States Available"
: "Verfügbare Lead Status"

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: "Möglicher Lead-Status mit den damit verbundenen Umsatzwahrscheinlichkeiten. Wenn ein Status markiert ist, werden Leads mit diesem Status als geschlossen behandelt."

, "open"
: "offen"

, "contacted"
: "kontaktiert"

, "waiting for feedback"
: "Wartet auf Feedback"

, "quote sent"
: "Quote gesendet"

, "accepted"
: "akzeptiert"

, "lost"
: "verloren"

, "Lead Sources Available"
: "Verfügbare Lead Quellen"

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: "Mögliche Lead-Quelle. Wenn eine Quelle als archiviert markiert ist, werden Leads dieser Quelle als geschlossen behandelt."

, "Lead Types Available"
: "Verfügbare Lead Typen"

, "Possible lead types."
: "Mögliche Lead Typen."

, "Reseller"
: "Reseller"

, "Enabled Features"
: "Feature aktivieren"

, "Enabled Features in Crm Application."
: "Features in der CRM Applikation aktivieren."

, "Lead Import"
: "Lead Import"

, "Add new task on lead import"
: "Füge eine neue Aufgabe beim Lead Import hinzu"

, "Automatically creates a task for the responsible person if a new lead is imported."
: "Lege automatisch eine neue Aufgabe für die verantwortliche Person an, wenn ein neuer Lead importiert wird."

, "Send notification email on lead import"
: "Sende Benachrichtigungen beim Lead Import"

, "Sends an email to all responsible persons for the imported leads."
: "Sende für die importierten Leads eine E-Mail an alle verantwortlichen Personen."

, "Lead duplicate check fields"
: "Lead-Dublettencheck Felder"

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "Diese Felder werden überprüft, wenn ein neuer Lead angelegt wird. Wenn ein Datensatz mit den selben Daten in diesem Feld gefunden wird, wird eine Dubletten Warnung geworfen."

, "State"
: "Status"

, "Source"
: "Quelle"

, "Scheduled end"
: "Geplantes Ende"

, "Folder"
: "Ordner"

, "Updated by"
: "Aktualisiert von"

, "Updated Fields:"
: "Geänderte Felder:"

, "'%s' changed from '%s' to '%s'."
: "'%s' wurde von '%s' auf '%s' geändert."

, "Lead %s has been changed"
: "Lead %s wurde geändert"

, "Lead %s has been deleted"
: "Lead %s wurde gelöscht"

, "Lead %s has been created"
: "Lead %s wurde angelegt"

, "Task"
: "Aufgabe"

, "Lead Data"
: "Lead-Daten"

, "End Scheduled"
: "Ende geplant"

, "Contacts"
: "Kontakte"

, "Telephone"
: "Telefon"

, "Email"
: "Email"

, "low"
: "Niedrig"

, "normal"
: "Normal"

, "high"
: "Hoch"

, "urgent"
: "Dringend"

, "Lead CSV import"
: "Lead CSV import"

, "Import list (###CURRENTDATE###)"
: "Importierte Liste (###CURRENTDATE###)"

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Leads importiert am ###CURRENTDATE### um ###CURRENTTIME### von ###USERFULLNAME###"

, "Edit new lead"
: "Neuen Lead bearbeiten"

, "The following leads have just been imported into lead list %s"
: "Die folgenden Leads wurden soeben in die Lead Liste %s importiert"

, "%s new leads have been imported"
: "%s neue Leads wurden importiert"

, "manage shared lead folders"
: "Gemeinsame Leads Ordner bearbeiten"

, "Create new shared lead folders"
: "Anlegen von gemeinsamen Leads Ordnern"

, "manage shared leads favorites"
: "Gemeinsame Lead-Favoriten verwalten"

, "Create or update shared leads favorites"
: "Gemeinsame Lead-Favoriten erstellen oder bearbeiten"

, "Get Notification E-mails"
: "Empfangen von Benachrichtigungs-E-Mails"

, "Send Notifications e-mails for own actions"
: "Sende Benachrichtigungen über eigene Änderungen"

, "Get notifications e-mails for actions you did yourself"
: "Empfangen von Benachrichtigungen über Änderungen die selbst getätigt wurden"

, "Send Notifications e-mails to responsible"
: "Sende Benachrichtigungen zu den Verantwortlichen"

, "Get notifications e-mails for action to responsible"
: "Empfangen von Benachrichtigungen über Änderungen für den Verantwortlichen"

, "Send Notifications e-mails to customer"
: "Sende Benachrichtigungen zu den Kunden"

, "Get notifications e-mails for action to customer"
: "Empfangen von Benachrichtigungen über Änderungen für den Kunden"

, "Send Notifications e-mails to partner"
: "Sende Benachrichtigungen zu den Partnern"

, "Get notifications e-mails for action to partner"
: "Empfangen von Benachrichtigungen über Änderungen für die Partner"

, "Enabled Features in CRM Application."
: "Features in der CRM Applikation aktivieren."

, "Send notification e-mail on lead import"
: "Sende Benachrichtigungen beim Lead Import"

, "Sends an e-mail to all responsible persons for the imported leads."
: "Sende für die importierten Leads eine E-Mail an alle verantwortlichen Personen."

, "All without me"
: "Alle außer mir"

, "All"
: "Alle"

, "Nobody"
: "Niemand"

, "send notification to responsible"
: "Versendet Benachrichtigungen zum Verantwortlichen"

, "send notification to customer"
: "Versendet Benachrichtigungen zum Kunden"

, "send notification to partner"
: "Versendet Benachrichtigungen zum Partner"

, "send notification"
: "Versendet Benachrichtigungen"

, "controls sending notification of Leads"
: "Steuert das versenden von Benachrichtigungen für Leads"

, "Lead"
: "Lead"

, "lead list"
: "Leadliste"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
